@@ -1,32 +1,55 @@
-#
-#	包名：Net::Telnet::Huawei
-#	功能：对华为系列交换机和路由器自动化操作
-#	引用方法：use Net::Telnet::Huawei;
-#
+
+=pod
+
+=encoding utf8
+
+=head1 NAME
+
+Net::Telnet::Huawei
+
+=head1 SYNOPSIS
+
+	use Net::Telnet::Huawei;
+	my $net_dev=Net::Telnet::Huawei->new;
+	my ($host, $user, $password, $super_password) = ('192.168.1.1', 'admin', 'password', 'super password');
+	$net_dev->login($host, $user, $password, $super_password);
+	my @lines = $net_dev->exec_cmd('display version');
+	print join("\n", @lines), "\n";
+
+=head1 DESCRIPTION
+
+  利用TELNET协议访问华为系列网络设备。
+
+=cut
 
 package Net::Telnet::Huawei;
 use parent 'Net::Telnet';
 use feature ':5.10';
-use POSIX qw(strftime);
 use Net::Ping;
-use YAML::Tiny;
-use File::Basename qw(dirname);
 use Array::Utils qw(:all);
 use Carp ();
-use Data::Dump qw(dump);
 use Devel::StackTrace;
-our $VERSION='0.0.1';
+use CPAN::Version;
+#use if CPAN::Version->vgt($^V,  'v5.10.1'), experimental => 'switch';
 
-use experimental 'switch';
+our $VERSION='0.0.2';
 
 my $debug=0;
 
-# DEBUG flag subroutine
 sub DEBUG(){
 	$debug;
 }
 
-# retrieve or set DEBUG flag
+=head2 Subs
+
+=over 4
+
+=item DEBUG
+
+Enable/Disable debug mode if passing an argument. Return debug mode if no argument.
+
+=cut
+
 sub debug{
 	my $self=shift;
 	$debug=shift if @_;
@@ -71,7 +94,13 @@ sub init_state{
 
 }
 
-# constructor
+
+=item new
+
+Constructor.
+
+=cut
+
 sub new {
 	my $class=shift;
 
@@ -84,7 +113,13 @@ sub new {
 	bless $self, $class;
 }
 
-# wait prompt
+
+=item wait_prompt
+
+Wait until prompt is found.
+
+=cut
+
 sub wait_prompt{
 	my $self=shift;
 	my $state=&get_state($self);
@@ -134,7 +169,12 @@ sub split_result{
 	@r;
 }
 
-# check if command exists
+=item can
+
+Check if a device command exists.
+
+=cut
+
 sub can{
 	my ($self, $cmd_name) =@_;
 
@@ -188,7 +228,12 @@ sub reset {
 	1;
 }
 
-# enable super privilege
+=item enter_super
+
+Enter privilege view.
+
+=cut
+
 sub enter_super {
 	my $self = shift;
 	my $su_password=shift;
@@ -229,7 +274,13 @@ sub enter_super {
 	return 1;
 }
 
-# 将当前登录的vty终端设置为不暂停状态
+
+=item set_vty_no_pause
+
+将当前登录的vty终端设置为不分页。
+
+=cut
+
 sub set_vty_no_pause {
 	my $self = shift;
 
@@ -257,7 +308,12 @@ sub set_vty_no_pause {
 	return 1;
 }
 
-# 将当前登录的vty终端设置为可暂停状态
+=item set_vty_pause
+
+ 将当前登录的vty终端设置为分页。
+
+=cut
+
 sub set_vty_pause {
 	my $self = shift;
 
@@ -288,7 +344,14 @@ sub set_vty_pause {
 	return 1;
 }
 
-# 必须处在提示符状态
+=item prompt_str
+
+返回当前提示符
+
+=back
+
+=cut
+
 sub prompt_str {
 	my $self = shift;
 	my $state=&get_state($self);
@@ -446,6 +509,8 @@ sub get_device_type {
 	\s*Quidway\s+(\S+)\s+Routing\s+Switch
 	|
 	\s*Quidway\s+(\S+)\s+Terabit\s+Routing\s+Switch
+	|
+	\s*H3C\s+(.+?)\s+uptime
 	/xi;
 
 	if($in =~ $r){
@@ -460,7 +525,7 @@ sub get_config_filename{
 
 	my $prematch = $self->exec_cmd('dir');
 	if($prematch){
-		$prematch =~ /((?:vrpcfg|config)\.(?:txt|zip|cfg))$/im;
+		$prematch =~ /((?:vrpcfg|config|startup)\.(?:txt|zip|cfg))$/im;
 		return $1 if defined $1;
 	}
 }
@@ -730,11 +795,17 @@ sub get_int_mac{
 	my @output_lines=$self->exec_cmd("display interface $port_base_name");
 	chomp @output_lines;
 
-	my @mac_address=grep /Hardware address is /, @output_lines;
+	my @mac_address=grep /address/i, @output_lines;
 	return unless @mac_address;
-	$mac_address[0] =~ /Hardware address is ([0-9a-fA-F]{4}-[0-9a-fA-F]{4}-[0-9a-fA-F]{4})$/;
 
-	my $mac = $1;
+
+	my $mac;
+	for(@mac_address){
+		if ( $_ =~ /([0-9a-fA-F]{4}-[0-9a-fA-F]{4}-[0-9a-fA-F]{4})$/){
+			$mac = $1;
+			last;
+		}
+	}
 
 	# 保存结果到缓存
 	if($device_type =~ /^S/i){
@@ -953,21 +1024,3 @@ sub get_state{
 
 __END__
 
-=pod
-
-=head1 User Manual
-
-	use Net::Telnet::Huawei;
-	my $nt = Net::Telnet::Huawei->new;
-	my $manage_ip = "manage ip address of the device";
-	my $username = "username";
-	my $password = "password of the device";
-	my $su_password = "super password of the device";
-	$nt->login($host, $username, $password);
-	$nt->enter_super($su_password);
-	my $data = $nt->exec_cmd("display version");
-	print $data;
-	$nt->logout;
-
-=cut
-
